pub struct NativePty { /* private fields */ }Expand description
Wrapper around the native PTY system.
Implementations
Sourceimpl NativePty
impl NativePty
Sourcepub fn spawn(
&self,
shell: &str,
size: PtySize,
) -> Result<PtyHandle<Box<dyn Read + Send>, Box<dyn Write + Send>>>
pub fn spawn( &self, shell: &str, size: PtySize, ) -> Result<PtyHandle<Box<dyn Read + Send>, Box<dyn Write + Send>>>
Sourcepub fn spawn_default(
&self,
size: PtySize,
) -> Result<PtyHandle<Box<dyn Read + Send>, Box<dyn Write + Send>>>
pub fn spawn_default( &self, size: PtySize, ) -> Result<PtyHandle<Box<dyn Read + Send>, Box<dyn Write + Send>>>
Spawn a shell process with the default shell.
Sourcepub fn spawn_shell(
&mut self,
working_dir: Option<&Path>,
) -> Result<SpawnedShell>
pub fn spawn_shell( &mut self, working_dir: Option<&Path>, ) -> Result<SpawnedShell>
Spawn a shell process with optional working directory.
This is a convenience method for command execution that spawns a shell with default size and optionally sets the working directory.
Sourcepub fn spawn_command(
&mut self,
command_line: &str,
working_dir: Option<&Path>,
) -> Result<SpawnedShell>
pub fn spawn_command( &mut self, command_line: &str, working_dir: Option<&Path>, ) -> Result<SpawnedShell>
Spawn a command directly (non-interactive).
This runs a single command and exits when done.
The command is executed via sh -c "command" (Unix) or cmd /c command (Windows).