pub struct Args {Show 23 fields
pub host: IpAddr,
pub port: u16,
pub config: Option<PathBuf>,
pub api_key: Option<String>,
pub no_auth: bool,
pub require_auth: bool,
pub capabilities: Vec<String>,
pub preset: Option<String>,
pub no_rate_limit: bool,
pub tunnel: bool,
pub tunnel_command: Option<String>,
pub relay: bool,
pub relay_url: Option<String>,
pub enroll_token: Option<String>,
pub public_base: Option<String>,
pub device_name: Option<String>,
pub cors_allow_any: bool,
pub log_level: Option<String>,
pub version: bool,
pub help: bool,
pub check_update: bool,
pub update: bool,
pub no_update_check: bool,
}Expand description
Command-line arguments.
Fields
host: IpAddrHost address to bind to.
port: u16Port to listen on.
config: Option<PathBuf>Path to configuration file.
api_key: Option<String>API key for authentication (overrides config file).
no_auth: boolDisable authentication.
require_auth: boolRequire authentication, auto-generating an API key if none is provided.
capabilities: Vec<String>Capability strings scoping the issued token(s) (empty = full-control).
preset: Option<String>Role preset scoping the issued token(s) (operator/read-only/full-control).
no_rate_limit: boolDisable rate limiting.
tunnel: boolExpose the server through a Cloudflare quick tunnel.
tunnel_command: Option<String>Expose the server through an arbitrary tunnel command.
relay: boolRun as a relay server (shell-tunnel relay) instead of a shell gateway.
relay_url: Option<String>Attach to this relay instead of publishing through a tunnel.
enroll_token: Option<String>Shared secret devices present to attach to this relay.
public_base: Option<String>Public base URL this relay is reachable at.
device_name: Option<String>Stable name to claim on the relay (keeps one URL across reconnects).
cors_allow_any: boolAllow any CORS origin (permissive; opt-in for browser UIs).
log_level: Option<String>Log level (error, warn, info, debug, trace).
version: boolShow version and exit.
help: boolShow help and exit.
check_update: boolCheck for updates and exit.
update: boolPerform self-update and exit.
no_update_check: boolDisable automatic update check on startup.