pub enum Posture {
Local,
Exposed,
}Expand description
How far this process is exposed.
Derived from arguments and not selectable by the user — there is no option to choose a posture, and there should not be one. What has already been chosen (tunnel, relay, bind address) determines the posture, and the posture determines the security defaults.
Variants
Local
Reachable only from this machine. No reason to narrow the defaults.
Exposed
Reachable from other machines — one or more of: tunnel, relay, or non-loopback bind.