pub struct Command {
pub command_line: String,
pub working_dir: Option<PathBuf>,
pub env: HashMap<String, String>,
pub timeout: Option<Duration>,
pub capture_output: bool,
}Expand description
A command to be executed in a shell session.
Fields
command_line: StringThe command line to execute.
working_dir: Option<PathBuf>Working directory override (if any).
env: HashMap<String, String>Environment variables to set.
timeout: Option<Duration>Maximum execution time.
capture_output: boolWhether to capture output.
Implementations
Sourceimpl Command
impl Command
Sourcepub fn new(command_line: impl Into<String>) -> Self
pub fn new(command_line: impl Into<String>) -> Self
Create a new command with the given command line.
Sourcepub fn working_dir(self, dir: impl Into<PathBuf>) -> Self
pub fn working_dir(self, dir: impl Into<PathBuf>) -> Self
Set the working directory.
Sourcepub fn env(self, key: impl Into<String>, value: impl Into<String>) -> Self
pub fn env(self, key: impl Into<String>, value: impl Into<String>) -> Self
Add an environment variable.
Sourcepub fn capture_output(self, capture: bool) -> Self
pub fn capture_output(self, capture: bool) -> Self
Set whether to capture output.