pub struct SessionStore { /* private fields */ }Expand description
Thread-safe storage for sessions.
Implementations
Sourceimpl SessionStore
impl SessionStore
Sourcepub fn create(&self, config: SessionConfig) -> Result<SessionId>
pub fn create(&self, config: SessionConfig) -> Result<SessionId>
Create a new session with the given configuration.
Returns the newly assigned session ID.
Sourcepub fn get(&self, id: &SessionId) -> Result<Option<Session>>
pub fn get(&self, id: &SessionId) -> Result<Option<Session>>
Get a clone of the session with the given ID.
Sourcepub fn update<F>(&self, id: &SessionId, f: F) -> Result<()>
pub fn update<F>(&self, id: &SessionId, f: F) -> Result<()>
Update a session using a closure.
The closure receives a mutable reference to the session and can modify it. Returns an error if the session doesn’t exist.